@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dashboard-ls" "0.3.0"
+(define-package "dashboard-ls" "20251231.1631"
   "Display files/directories in current directory on Dashboard."
-  '((emacs     "24.3")
+  '((emacs     "27.1")
     (dashboard "1.2.5"))
   :url "https://github.com/emacs-dashboard/dashboard-ls"
-  :commit "5c6a11bfda542892775b5c55c8430773cc82b3c9"
-  :revdesc "5c6a11bfda54"
+  :commit "e6f1ae4e4f4efbc1d3c4cff84b220f44e963e6ab"
+  :revdesc "e6f1ae4e4f4e"
+  :keywords '("convenience" "directory" "file" "show")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
